<?php
namespace Dominie\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
* Elementor Widget
* Elementor widget for Dominie.
* @since 1.0.0
**/
class Dmne_Course extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	**/
	public function get_name() {
		return 'dmne-course';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Dmne Course', 'dominie' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-group';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'dominie_widgets' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'dominie' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'dominie' ),
			]
		);

		$this->add_control(
			'course-style',
			[
				'label' => __( 'Course Style', 'dominie' ),
				'type' => Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'1' => __( 'Course Grid', 'dominie' ),
					'2' => __( 'Course Grid 2', 'dominie' ),
					'3' => __( 'Course Slider', 'dominie' ),
					'4' => __( 'Course Slider 2', 'dominie' ),
					'5' => __( 'Course Mesonary', 'dominie' ),
					'6' => __( 'Course List Slider', 'dominie' ),
				],
			]
		);

		$this->add_control(
			'course-column',
			[
				'label' => __( 'Course Column Style', 'dominie' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'col-lg-4',
				'options' => [
					'col-lg-4' => __( 'col-lg-4', 'dominie' ),
					'col-lg-6' => __( 'col-lg-6', 'dominie' ),
					'col-lg-3' => __( 'col-lg-3', 'dominie' ),
				],
			]
		);

		$this->add_control(
			'post-order',
			[
				'label' => __( 'Post Order', 'dominie' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'ASC',
				'options' => [
					'ASC' => __( 'ASC', 'dominie' ),
					'DSC' => __( 'DSC', 'dominie' ),
				],
			]
		);
		$this->add_control(
			'post-limit',
			[
				'label'       => esc_html__( 'Post Limit', 'dominie' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'How Many Post You Display', 'dominie' ),
				'default'     => esc_html__('-1','dominie')
			]
		);
		$this->add_control(
			'post-offset',
			[
				'label'       => esc_html__( 'Post Offset', 'dominie' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'How Many Post You Offset', 'dominie' ),
				'default'     => esc_html__('0','dominie')
			]
		);
		$this->end_controls_section();


		$this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'dominie' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		//color style field
		$this->add_control(
			'price-bg-color',
			[
				'label' => __( 'Price Bg Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .single-course-inner .details .price' => 'background: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'slider-control-color',
			[
				'label' => __( 'Slider Control Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .owl-dots .owl-dot.active' => 'background: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'text_transform',
			[
				'label' => esc_html__( 'Text Transform', 'dominie' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => esc_html__( 'None', 'dominie' ),
					'uppercase' => esc_html__( 'UPPERCASE', 'dominie' ),
					'lowercase' => esc_html__( 'lowercase', 'dominie' ),
					'capitalize' => esc_html__( 'Capitalize', 'dominie' ),
				],
				'selectors' => [
					'{{WRAPPER}} .title' => 'text-transform: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	*/
	protected function render() {
		$settings = $this->get_settings_for_display(); 
		$course_column  = (isset($settings['course-column']) ? $settings['course-column'] : 'col-lg-4');  ?>

		<div class="course-area">

			<?php global $post; 
			$course_query = new \WP_Query(array('post_type'=> 'courses', 'order'=> $settings['post-order'], 'posts_per_page' => $settings['post-limit'], 'offset' => $settings['post-offset'] ));

			if($settings['course-style'] == 2){ ?>
				<div class="row justify-content-center">
					<?php 
						if($course_query->have_posts()) : 
							while($course_query->have_posts()) : $course_query->the_post(); ?> 
								<div class="<?php echo $course_column ?> col-md-6">
				                    <div class="single-course-inner">
										<div class="tutor-course-header">
											<?php
												$course_id = get_the_ID();
											?>
										    <div class="tutor-course-loop-header-meta">
												<?php
										        $is_wishlisted = tutor_utils()->is_wishlisted($course_id);
										        $has_wish_list = '';
										        if ($is_wishlisted){
											        $has_wish_list = 'has-wish-listed';
										        }

										        $action_class = '';
										        if ( is_user_logged_in()){
										            $action_class = apply_filters('tutor_wishlist_btn_class', 'tutor-course-wishlist-btn');
										        }else{
										            $action_class = apply_filters('tutor_popup_login_class', 'cart-required-login');
										        }

												echo '<span class="tutor-course-loop-level">'.get_tutor_course_level().'</span>';
												echo '<span class="tutor-course-wishlist"><a href="javascript:;" class="tutor-icon-fav-line '.$action_class.' '.$has_wish_list.' " data-course-id="'.$course_id.'"></a> </span>';
												?>
										    </div>
										</div>



				                        <div class="thumb">
				                        	
				                            <?php
				                            	echo get_the_post_thumbnail( null, 'course-grid-thumbnail-2', array('class'=> 'img-responsive') );
				                            ?>
				                        </div>
				                        <div class="details">
				                            <?php 
	                                    		$course_id = get_the_ID();
												$price_html = '<div class="price">'.__('Free', 'dominie').'</div>';
												if (tutor_utils()->is_course_purchasable()) {

												    $product_id = tutor_utils()->get_course_product_id($course_id);
												    $product    = wc_get_product( $product_id );

												    if ( $product ) {
													    $price_html = '<div class="price">'.$product->get_price_html().'</div>';
												    }
												}
												echo $price_html; 
											?>
				                            <div class="meta">
				                                <div class="row">
				                                    <div class="col-6">
				                                    	<?php 
				                                    		$categories = get_the_terms( $post->ID, 'course-category' );
															foreach( $categories as $category ) {
															    $allCategorys[$category->slug] = $category->name;
															}
															foreach ($allCategorys as $catSlug => $catName) { ?>
																
															<?php }
				                                    	?>
				                                        <p><?php echo $catName ?></p>
				                                    </div>
				                                </div>
				                            </div>
				                            <h5><a href="<?php echo get_the_permalink(); ?>"><?php echo get_the_title(); ?></a></h5>
				                            <div class="meta">
				                                <div class="row">
				                                    <div class="col-6">
				                                        <p><?php echo tutor_utils()->count_enrolled_users_by_course() . esc_html__(' students', 'dominie') ?></p>
				                                    </div>
				                                    <div class="col-6 text-right">
				                                        <p><?php print get_tutor_course_duration_context() ?></p>
				                                    </div>
				                                </div>
				                            </div>
				                        </div>
				                    </div>
				                </div>
							<?php endwhile;
						endif;
					?>
				</div>
			<?php } elseif($settings['course-style'] == 3){ ?>
				<div class="courses-slider owl-carousel">
					<?php if($course_query->have_posts()) : 
						while($course_query->have_posts()) : $course_query->the_post(); ?>

							<div class="item">
			                    <div class="single-course-inner">
									<div class="tutor-course-header">
										<?php
											$course_id = get_the_ID();
										?>
									    <div class="tutor-course-loop-header-meta">
											<?php
									        $is_wishlisted = tutor_utils()->is_wishlisted($course_id);
									        $has_wish_list = '';
									        if ($is_wishlisted){
										        $has_wish_list = 'has-wish-listed';
									        }

									        $action_class = '';
									        if ( is_user_logged_in()){
									            $action_class = apply_filters('tutor_wishlist_btn_class', 'tutor-course-wishlist-btn');
									        }else{
									            $action_class = apply_filters('tutor_popup_login_class', 'cart-required-login');
									        }

											echo '<span class="tutor-course-loop-level">'.get_tutor_course_level().'</span>';
											echo '<span class="tutor-course-wishlist"><a href="javascript:;" class="tutor-icon-fav-line '.$action_class.' '.$has_wish_list.' " data-course-id="'.$course_id.'"></a> </span>';
											?>
									    </div>
									</div>
			                        <div class="thumb">
			                            <?php
										tutor_course_loop_thumbnail();
										$course_id = get_the_ID(); ?>
									    <div class="tutor-course-loop-header-meta">
											<?php
									        $is_wishlisted = tutor_utils()->is_wishlisted($course_id);
									        $has_wish_list = '';
									        if ($is_wishlisted){
										        $has_wish_list = 'has-wish-listed';
									        }

									        $action_class = '';
									        if ( is_user_logged_in()){
									            $action_class = apply_filters('tutor_wishlist_btn_class', 'tutor-course-wishlist-btn');
									        }else{
									            $action_class = apply_filters('tutor_popup_login_class', 'cart-required-login');
									        }
											echo '<span class="tutor-course-wishlist"><a href="javascript:;" class="tutor-icon-fav-line '.$action_class.' '.$has_wish_list.' " data-course-id="'.$course_id.'"></a> </span>'; ?>
									    </div>						
										
										<?php
											$course_rating = tutor_utils()->get_course_rating();
										    if (!empty($course_rating)) { ?>
												<?php 
													if ($course_rating->rating_avg > 0) { ?>
														<div class="rating">
									        				<?php echo  apply_filters('tutor_course_rating_average', $course_rating->rating_avg);
									        				echo '/5 <i class="fa fa-star"></i>'; ?>
									        			</div>
													<?php } 
												?>
											<?php }
										?>
			                        </div>
			                        <div class="details">
			                            <div class="meta">
			                                <div class="row">
			                                    <div class="col-6">
			                                        <p><?php echo tutor_utils()->count_enrolled_users_by_course() . esc_html__(' students', 'dominie') ?></p>
			                                    </div>
			                                    <div class="col-6 text-right">
			                                        <p><?php print get_tutor_course_duration_context() ?></p>
			                                    </div>
			                                </div>
			                            </div>
			                            <h5><a href="<?php echo get_the_permalink(); ?>"><?php echo get_the_title(); ?></a></h5>
			                            <div class="price-inner">
			                                <div class="row">
			                                    <div class="col-6">
			                                    	<?php 
			                                    		$course_id = get_the_ID();
														$price_html = '<p>'.__('Free', 'dominie').'</p>';
														if (tutor_utils()->is_course_purchasable()) {

														    $product_id = tutor_utils()->get_course_product_id($course_id);
														    $product    = wc_get_product( $product_id );

														    if ( $product ) {
															    $price_html = '<p>'.$product->get_price_html().'</p>';
														    }
														}
														echo $price_html; 
													?>
			                                    </div>
			                                    <div class="col-6 text-right">
			                                        <a href="<?php echo get_the_permalink(); ?>"><i class="fa fa-shopping-cart"></i></a>
			                                    </div>
			                                </div>
			                            </div>
			                        </div>
			                    </div>
			                </div>
			                
						<?php endwhile;
						wp_reset_postdata();
					endif; ?>
				</div>
			<?php } elseif($settings['course-style'] == 4){ ?>
				<div class="courses-slider owl-carousel">
					<?php 
						if($course_query->have_posts()) : 
							while($course_query->have_posts()) : $course_query->the_post(); ?> 
								<div class="item">
				                    <div class="single-course-inner">
										<div class="tutor-course-header">
											<?php
												$course_id = get_the_ID();
											?>
										    <div class="tutor-course-loop-header-meta">
												<?php
										        $is_wishlisted = tutor_utils()->is_wishlisted($course_id);
										        $has_wish_list = '';
										        if ($is_wishlisted){
											        $has_wish_list = 'has-wish-listed';
										        }

										        $action_class = '';
										        if ( is_user_logged_in()){
										            $action_class = apply_filters('tutor_wishlist_btn_class', 'tutor-course-wishlist-btn');
										        }else{
										            $action_class = apply_filters('tutor_popup_login_class', 'cart-required-login');
										        }

												echo '<span class="tutor-course-loop-level">'.get_tutor_course_level().'</span>';
												echo '<span class="tutor-course-wishlist"><a href="javascript:;" class="tutor-icon-fav-line '.$action_class.' '.$has_wish_list.' " data-course-id="'.$course_id.'"></a> </span>';
												?>
										    </div>
										</div>
				                        <div class="thumb">
				                            <?php
				                            	echo get_the_post_thumbnail( null, 'course-grid-thumbnail-2', array('class'=> 'img-responsive') );
				                            ?>
				                        </div>
				                        <div class="details">
				                            <?php 
	                                    		$course_id = get_the_ID();
												$price_html = '<div class="price">'.__('Free', 'dominie').'</div>';
												if (tutor_utils()->is_course_purchasable()) {

												    $product_id = tutor_utils()->get_course_product_id($course_id);
												    $product    = wc_get_product( $product_id );

												    if ( $product ) {
													    $price_html = '<div class="price">'.$product->get_price_html().'</div>';
												    }
												}
												echo $price_html; 
											?>
				                            <div class="meta">
				                                <div class="row">
				                                    <div class="col-6">
				                                    	<?php 
				                                    		$categories = get_the_terms( $post->ID, 'course-category' );
															foreach( $categories as $category ) {
															    $allCategorys[$category->slug] = $category->name;
															}
															foreach ($allCategorys as $catSlug => $catName) { ?>
																
															<?php }
				                                    	?>
				                                        <p><?php echo $catName ?></p>
				                                    </div>
				                                </div>
				                            </div>
				                            <h5><a href="<?php echo get_the_permalink(); ?>"><?php echo get_the_title(); ?></a></h5>
				                            <div class="meta">
				                                <div class="row">
				                                    <div class="col-6">
				                                        <p><?php echo tutor_utils()->count_enrolled_users_by_course() . esc_html__(' students', 'dominie') ?></p>
				                                    </div>
				                                    <div class="col-6 text-right">
				                                        <p><?php print get_tutor_course_duration_context() ?></p>
				                                    </div>
				                                </div>
				                            </div>
				                        </div>
				                    </div>
				                </div>
							<?php endwhile;
						endif;
					?>
				</div>
			<?php } elseif($settings['course-style'] == 5){ ?>
				<div class="work-area">
		        	<?php if($course_query->have_posts()) : 
						while($course_query->have_posts()) : $course_query->the_post();
							$categories = get_the_terms( $post->ID, 'course-category' );
							if(!empty($categories)) {
								foreach( $categories as $category ) {
								    $allCategorys[$category->slug] = $category->name;
								}
							}
						endwhile;
					endif; ?>
		            <div class="dmne-mesonary-inner isotope-filters item-isotope-btn text-center">
		                <button class="button active ml-0" data-filter="*"><?php echo esc_html__( 'All Categories', 'dominie' ) ?></button>
		                <?php 
			                if(!empty($categories)) {
				                foreach ($allCategorys as $catSlug => $catName) { ?>
									<button class="button" data-filter=".<?php echo $catSlug ?>"><?php echo $catName ?></button>			
								<?php }
							}  
						?>
		            </div>
		            <div class="all-item-section">        
		                <div class="item-isotope row justify-content-center">
		                    <div class="item-sizer col-1"></div>
		                    <?php if($course_query->have_posts()) : 
							while($course_query->have_posts()) : $course_query->the_post(); 
								$post_categories = get_the_terms( $post->ID, 'course-category' );
								if ( ! empty( $post_categories ) && ! is_wp_error( $post_categories ) ) {
								    $currentCategories = wp_list_pluck( $post_categories, 'slug' );
								} ?>

			                    <div class="all-isotope-item <?php echo $course_column ?> col-md-6 <?php echo implode(' ', $currentCategories) ?>">
			                        <div class="single-course-inner">
				                        <div class="thumb">
				                            <?php
											tutor_course_loop_thumbnail();
											$course_id = get_the_ID(); ?>
										    <div class="tutor-course-loop-header-meta">
												<?php
										        $is_wishlisted = tutor_utils()->is_wishlisted($course_id);
										        $has_wish_list = '';
										        if ($is_wishlisted){
											        $has_wish_list = 'has-wish-listed';
										        }

										        $action_class = '';
										        if ( is_user_logged_in()){
										            $action_class = apply_filters('tutor_wishlist_btn_class', 'tutor-course-wishlist-btn');
										        }else{
										            $action_class = apply_filters('tutor_popup_login_class', 'cart-required-login');
										        }
												echo '<span class="tutor-course-wishlist"><a href="javascript:;" class="tutor-icon-fav-line '.$action_class.' '.$has_wish_list.' " data-course-id="'.$course_id.'"></a> </span>'; ?>
										    </div>						
											
											<?php
												$course_rating = tutor_utils()->get_course_rating();
											    if (!empty($course_rating)) { ?>
													<?php 
														if ($course_rating->rating_avg > 0) { ?>
															<div class="rating">
										        				<?php echo  apply_filters('tutor_course_rating_average', $course_rating->rating_avg);
										        				echo '/5 <i class="fa fa-star"></i>'; ?>
										        			</div>
														<?php } 
													?>
												<?php }
											?>
				                        </div>
				                        <div class="details">
				                            <div class="meta">
				                                <div class="row">
				                                    <div class="col-6">
				                                        <p><?php echo tutor_utils()->count_enrolled_users_by_course() . esc_html__(' students', 'dominie') ?></p>
				                                    </div>
				                                    <div class="col-6 text-right">
				                                        <p><?php print get_tutor_course_duration_context() ?></p>
				                                    </div>
				                                </div>
				                            </div>
				                            <h5><a href="<?php echo get_the_permalink(); ?>"><?php echo get_the_title(); ?></a></h5>
				                            <div class="price-inner">
				                                <div class="row">
				                                    <div class="col-6">
				                                    	<?php 
				                                    		$course_id = get_the_ID();
															$price_html = '<p>'.__('Free', 'dominie').'</p>';
															if (tutor_utils()->is_course_purchasable()) {

															    $product_id = tutor_utils()->get_course_product_id($course_id);
															    $product    = wc_get_product( $product_id );

															    if ( $product ) {
																    $price_html = '<p>'.$product->get_price_html().'</p>';
															    }
															}
															echo $price_html; 
														?>
				                                    </div>
				                                    <div class="col-6 text-right">
				                                        <a href="<?php echo get_the_permalink(); ?>"><i class="fa fa-shopping-cart"></i></a>
				                                    </div>
				                                </div>
				                            </div>
				                        </div>
				                    </div>
			                    </div>
				            <?php endwhile;
							endif; ?>
		                </div>
			        </div>
			    </div>
			<?php } elseif($settings['course-style'] == 6){ ?>
				<div class="welcome-slider owl-carousel">
					<?php 
						if($course_query->have_posts()) : 
							while($course_query->have_posts()) : $course_query->the_post(); ?> 
				                <div class="item">
				                    <div class="single-video-inner">
				                        <div class="row">
				                            <div class="col-md-6">
												<div class="tutor-course-header">
													<?php
														$course_id = get_the_ID();
													?>
												    <div class="tutor-course-loop-header-meta">
														<?php
												        $is_wishlisted = tutor_utils()->is_wishlisted($course_id);
												        $has_wish_list = '';
												        if ($is_wishlisted){
													        $has_wish_list = 'has-wish-listed';
												        }

												        $action_class = '';
												        if ( is_user_logged_in()){
												            $action_class = apply_filters('tutor_wishlist_btn_class', 'tutor-course-wishlist-btn');
												        }else{
												            $action_class = apply_filters('tutor_popup_login_class', 'cart-required-login');
												        }

														echo '<span class="tutor-course-loop-level">'.get_tutor_course_level().'</span>';
														echo '<span class="tutor-course-wishlist"><a href="javascript:;" class="tutor-icon-fav-line '.$action_class.' '.$has_wish_list.' " data-course-id="'.$course_id.'"></a> </span>';
														?>
												    </div>
												</div>
				                                <div class="thumb">
				                                    <?php
						                            	echo get_the_post_thumbnail( null, 'course-list-thumbnail', array('class'=> 'img-responsive') );
						                            ?>
				                                </div>
				                            </div>
				                            <div class="col-md-6 align-self-center">
				                                <div class="details">
				                                    <h5><a href="<?php echo get_the_permalink(); ?>"><?php echo get_the_title(); ?></a></h5>
				                                    <p><?php the_author() ?></p>

				                                    <?php $completed_count = tutor_utils()->get_course_completed_percent(); ?>
				                                    <div class="progress">
				                                        <div class="progress-bar" role="progressbar" aria-valuenow="60"
				                                        aria-valuemin="0" aria-valuemax="100" style="width: <?php echo $completed_count.'%;'; ?>"></div>
				                                    </div>
				                                    <div class="meta"><?php echo $completed_count; ?>% <?php _e(' Complete', 'dominie')?></div>
				                                </div>
				                            </div>
				                        </div>
				                    </div>
				                </div>
	            			<?php endwhile;
						endif;
					?>
	            </div>
			<?php }else { ?>
				<div class="row justify-content-center">
					<?php if($course_query->have_posts()) : 
						while($course_query->have_posts()) : $course_query->the_post(); ?>

							<div class="<?php echo $course_column ?> col-md-6">
			                    <div class="single-course-inner">
			                        <div class="thumb">
			                            <?php
										tutor_course_loop_thumbnail();
										$course_id = get_the_ID(); ?>
									    <div class="tutor-course-loop-header-meta">
											<?php
									        $is_wishlisted = tutor_utils()->is_wishlisted($course_id);
									        $has_wish_list = '';
									        if ($is_wishlisted){
										        $has_wish_list = 'has-wish-listed';
									        }

									        $action_class = '';
									        if ( is_user_logged_in()){
									            $action_class = apply_filters('tutor_wishlist_btn_class', 'tutor-course-wishlist-btn');
									        }else{
									            $action_class = apply_filters('tutor_popup_login_class', 'cart-required-login');
									        }
											echo '<span class="tutor-course-wishlist"><a href="javascript:;" class="tutor-icon-fav-line '.$action_class.' '.$has_wish_list.' " data-course-id="'.$course_id.'"></a> </span>'; ?>
									    </div>						
										
										<?php
											$course_rating = tutor_utils()->get_course_rating();
										    if (!empty($course_rating)) { ?>
												<?php 
													if ($course_rating->rating_avg > 0) { ?>
														<div class="rating">
									        				<?php echo  apply_filters('tutor_course_rating_average', $course_rating->rating_avg);
									        				echo '/5 <i class="fa fa-star"></i>'; ?>
									        			</div>
													<?php } 
												?>
											<?php }
										?>
			                        </div>
			                        <div class="details">
			                            <div class="meta">
			                                <div class="row">
			                                    <div class="col-6">
			                                        <p><?php echo tutor_utils()->count_enrolled_users_by_course() . esc_html__(' students', 'dominie') ?></p>
			                                    </div>
			                                    <div class="col-6 text-right">
			                                        <p><?php print get_tutor_course_duration_context() ?></p>
			                                    </div>
			                                </div>
			                            </div>
			                            <h5><a href="<?php echo get_the_permalink(); ?>"><?php echo get_the_title(); ?></a></h5>
			                            <div class="price-inner">
			                                <div class="row">
			                                    <div class="col-6">
			                                    	<?php 
			                                    		$course_id = get_the_ID();
														$price_html = '<p>'.__('Free', 'dominie').'</p>';
														if (tutor_utils()->is_course_purchasable()) {

														    $product_id = tutor_utils()->get_course_product_id($course_id);
														    $product    = wc_get_product( $product_id );

														    if ( $product ) {
															    $price_html = '<p>'.$product->get_price_html().'</p>';
														    }
														}
														echo $price_html; 
													?>
			                                    </div>
			                                    <div class="col-6 text-right">
			                                        <a href="<?php echo get_the_permalink(); ?>"><i class="fa fa-shopping-cart"></i></a>
			                                    </div>
			                                </div>
			                            </div>
			                        </div>
			                    </div>
			                </div>
			                
						<?php endwhile;
						wp_reset_postdata();
					endif; ?>
				</div>
			<?php } ?>
		</div>
	<?php }
}