<?php
namespace Dominie\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
* Elementor Widget
* Elementor widget for Dominie.
* @since 1.0.0
**/
class Dmne_Testimonial extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	**/
	public function get_name() {
		return 'dmne-testimonial';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Dmne Testimonial', 'dominie' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-testimonial';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'dominie_widgets' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'dominie' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'dominie' ),
			]
		);

		$this->add_control(
			'testimonial-style',
			[
				'label' => __( 'Banner Style', 'dominie' ),
				'type' => Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'1' => __( 'Testimonial 1', 'dominie' ),
					'2' => __( 'Testimonial 2', 'dominie' ),
					'3' => __( 'Testimonial 3', 'dominie' ),
				],
			]
		);

		$this->add_control(
			'post-order',
			[
				'label' => __( 'Post Order', 'dominie' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'ASC',
				'options' => [
					'ASC' => __( 'ASC', 'dominie' ),
					'DSC' => __( 'DSC', 'dominie' ),
				],
			]
		);
		$this->add_control(
			'post-limit',
			[
				'label'       => esc_html__( 'Post Limit', 'dominie' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'How Many Post You Display', 'dominie' ),
				'default'     => esc_html__('-1','dominie')
			]
		);



		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'dominie' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		//color style field
		$this->add_control(
			'image-border-color',
			[
				'label' => __( 'Image Border Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .testimonial-thumbnail-carousel img' => 'border: 4px solid {{VALUE}} !important;',
				],
			]
		);
		$this->add_control(
			'image-hover-bg',
			[
				'label' => __( 'Image Hover BG', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .testimonial-thumbnail-carousel .video-play-btn' => 'background: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'slider-control-color',
			[
				'label' => __( 'Slider Control Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .slick-dots li.slick-active' => 'background: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'text_transform',
			[
				'label' => esc_html__( 'Text Transform', 'dominie' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => esc_html__( 'None', 'dominie' ),
					'uppercase' => esc_html__( 'UPPERCASE', 'dominie' ),
					'lowercase' => esc_html__( 'lowercase', 'dominie' ),
					'capitalize' => esc_html__( 'Capitalize', 'dominie' ),
				],
				'selectors' => [
					'{{WRAPPER}} .title' => 'text-transform: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	*/
	protected function render() {
		$settings = $this->get_settings_for_display(); ?>

		<?php if ($settings['testimonial-style'] == 2) { ?>
			<div class="testimonial-area">
	            <div class="row justify-content-center">
	                <div class="col-lg-7 col-md-11">
	                    <div class="testimonial-thumbnail-carousel">
                    		<?php $testimonial_query = new \WP_Query(array('post_type'=> 'testimonial', 'order'=> $settings['post-order'], 'posts_per_page' => $settings['post-limit'] ));

							if($testimonial_query->have_posts()) : 
								while($testimonial_query->have_posts()) : $testimonial_query->the_post(); 
		                    		$testimonial_video = get_post_meta( get_the_ID(), '__dominie__testimonial_video', true ); ?>

	                    		 	<div class="single-thumbnail-item">
			                        	<?php echo get_the_post_thumbnail( null, 'testimonial-slider-thumbnail', array('class'=> 'img-responsive') ) ?>
			                        	<a href="<?php echo $testimonial_video; ?>" class="video-btn video-play-btn mfp-iframe" tabindex="0"><i class="fa fa-play"></i></a>
			                        </div>
		                    		
			                	<?php endwhile;
								wp_reset_postdata();
							endif;	?>

	                    </div>
	                </div>
	                <div class="col-lg-6">
	                    <div class="testimonial-thumbnail-slider">
	                    	<?php $testimonial_query = new \WP_Query(array('post_type'=> 'testimonial', 'order'=> $settings['post-order'], 'posts_per_page' => $settings['post-limit'] ));

							if($testimonial_query->have_posts()) : 
								while($testimonial_query->have_posts()) : $testimonial_query->the_post(); ?>
			                        <div class="slider-item text-center">
			                            <h5><?php echo get_the_title(); ?></h5>
			                            <span>Bostsolf.co</span>
			                            <p><?php print wp_trim_words( get_the_content(), 25, null ); ?></p>
			                        </div>
		                       <?php endwhile;
								wp_reset_postdata();
							endif;	?>
	                    </div>
	                </div>
	            </div>
		    </div>
		<?php } elseif($settings['testimonial-style'] == 3){ ?>
			<div class="feedback-slider-area">
				<div class="feedback-slider owl-carousel">
					<?php $testimonial_query = new \WP_Query(array('post_type'=> 'testimonial', 'order'=> $settings['post-order'], 'posts_per_page' => $settings['post-limit'] ));

					if($testimonial_query->have_posts()) : 
						while($testimonial_query->have_posts()) : $testimonial_query->the_post(); ?>

				            <div class="item">
				                <div class="single-feedback-inner">
			                    	<?php 
			                    		$testimonial_image = get_post_meta( get_the_ID(), '__dominie__testimonial_image', true );
			                    		$testimonial_designation = get_post_meta( get_the_ID(), '__dominie__testimonial_designation', true );

			                    		if (!empty($testimonial_image)) { ?>
			                    		 	<div class="thumb">
					                        	<img src="<?php echo $testimonial_image ?>" alt="<?php echo esc_html_e('img','dominie') ?>">
					                        </div>
			                    		<?php } 
			                    	?>
			                        <div class="details mb-4">
			                            <p><?php echo get_the_content(); ?></p>
			                        </div>
			                        <div class="media">
			                            <div class="media-left">
			                            	<?php echo get_the_post_thumbnail( null, 'testimonial-grid-thumbnail', array('class'=> 'img-responsive') ) ?>
			                            </div>
			                            <div class="media-body align-self-center">
			                                <h6><?php echo get_the_title(); ?></h6>
			                                <p><?php echo $testimonial_designation; ?></p>
			                            </div>
			                        </div>
			                    </div>
				            </div>

			            <?php endwhile;
						wp_reset_postdata();
					endif;	?>
		        </div>
	        </div>
		<?php }else { ?>
			<div class="feedback-intro-area">
				<div class="feedback-filter-area row">
	        		<div class="fdb-sizer col-1"></div>

					<?php $testimonial_query = new \WP_Query(array('post_type'=> 'testimonial', 'order'=> $settings['post-order'], 'posts_per_page' => $settings['post-limit'] ));

					$i = 1;

					if($testimonial_query->have_posts()) : 
						while($testimonial_query->have_posts()) : $testimonial_query->the_post(); ?>

							<?php
								if($i % 2 == 0){
									$j = 'style-two';
								}else {
									$j = '';
								}
							?>
							<div class="dmne-fdb-item col-lg-4 col-md-6">
			                    <div class="single-feedback-inner <?php echo $j ?>">
			                    	<?php 
			                    		$testimonial_image = get_post_meta( get_the_ID(), '__dominie__testimonial_image', true );
			                    		$testimonial_designation = get_post_meta( get_the_ID(), '__dominie__testimonial_designation', true );

			                    		if (!empty($testimonial_image)) { ?>
			                    		 	<div class="thumb">
					                        	<img src="<?php echo $testimonial_image ?>" alt="<?php esc_html_e('img','dominie') ?>">
					                        </div>
			                    		<?php } 
			                    	?>
			                        <div class="details mb-4">
			                            <p><?php echo get_the_content(); ?></p>
			                        </div>
			                        <div class="media">
			                            <div class="media-left">
			                            	<?php echo get_the_post_thumbnail( null, 'testimonial-grid-thumbnail', array('class'=> 'img-responsive') ) ?>
			                            </div>
			                            <div class="media-body align-self-center">
			                                <h6><?php echo get_the_title(); ?></h6>
			                                <p><?php echo $testimonial_designation ?></p>
			                            </div>
			                        </div>
			                    </div>
			                </div>
			                
						<?php $i++; endwhile;
						wp_reset_postdata();
					endif;	?>

				</div>
			</div>
		<?php } 
	}
}